@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.72 2005/09/15 16:45:27 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.77 2006/03/28 19:23:33 richb Exp $
  *
- *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -328,6 +328,9 @@ do_expression()
     update_statusbar("", "");
 
     btext = (v->current->symname) ? v->current->symname : v->current->str;
+    if (v->current->flags & dpoint) {
+	btext = get_localized_numeric_point();
+    }
     btext = gc_strdup(btext);
     trig_filter(&btext);
   
@@ -424,6 +427,9 @@ do_expression()
 		case -PARSER_ERR_TOO_LONG_NUMBER:
 		    message = _("Too long number");
 		    break;
+		case -PARSER_ERR_BITWISEOP:
+		    message = _("Invalid bitwise operation parameter(s)");
+		    break;
 		default:
 		    message = _("Malformed expression");
 		    break;
@@ -586,6 +592,7 @@ do_trig()
 {
     do_trigfunc(v->MPdisp_val, v->MPresult);
     show_display(v->MPresult);
+    mpstr(v->MPresult, v->MPdisp_val);
 }
 
 
@@ -951,15 +958,14 @@ do_memory()
 
 
 void
-do_mode()                   /* Set special calculator mode. */
+do_mode(int toclear)           /* Set special calculator mode. */
 {
-    char title[MAXLINE];
-
-    SPRINTF(title, "%s - %s", v->tool_label, _(mstrs[(int) v->modetype]));
-    set_title(FCP_KEY, title);
+    set_main_title(v->modetype);
     put_resource(R_MODE, Rmstr[(int) v->modetype]);
     set_mode(v->modetype);
-    do_clear();
+    if (toclear) {
+        do_clear();
+    }
 }
 
 
@@ -1417,6 +1423,20 @@ save_pending_values(struct button *but)
 }
 
 
+void
+set_main_title(enum mode_type modetype)  /* Set the title for main window. */
+{
+    char title[MAXLINE];
+
+    if (modetype == BASIC) {
+        STRCPY(title, v->tool_label);
+    } else {
+        SPRINTF(title, "%s - %s", v->tool_label, _(mstrs[(int) modetype]));
+    }
+    set_title(FCP_KEY, title);
+}
+
+
 void
 show_error(char *message)
 {
